Breakpoint

Struct Breakpoint 

pub struct Breakpoint {
    pub source: String,
    pub line: Option<u64>,
}
Breakpoint definition

Fields

source: String

Source pattern that will trigger the breakpoint

line: Option<u64>

Line of the source that will trigger the breakpoin. If None, any incidence of source will trigger the breakpoint, regardless of the line.

Implementations

Source

impl Breakpoint

pub fn matches(&self, source: &str, line: u64) -> bool

Check if breakpoint matches the given arguments