pub struct CircuitDescription<S> { /* private fields */ }
A circuit description file

Since circuit descriptions are often large, it will perform lazy disk I/O, loading only the required data to satisfy the user operation.

Implementations

Open a CDF file as read-only.

Create a new instance of the CDF consumer by reference

Create a new context with a referennce to the underlying source

Create a new circuit description instance.

Attempt to read an indexed constraint from the source

Attempt to read an indexed witness from the source

Attempt to fetch a path from source cache

Return the inner source

CDF file metadata

CDF preamble metadata