pub struct Context<S> { /* private fields */ }Expand description
Encoding and decoding context to be defined by the reader/writer and consumed by the elements
Implementations
sourceimpl<S> Context<S>
impl<S> Context<S>
sourcepub fn with_source_cache_id(&mut self, id: usize) -> &mut Self
pub fn with_source_cache_id(&mut self, id: usize) -> &mut Self
Set a source cache id in the context. The next witness or constraint encoding should consume it instead of storing the raw path
sourcepub fn take_source_cache_id(&mut self) -> Option<usize>
pub fn take_source_cache_id(&mut self) -> Option<usize>
Consume a previously set source cache id.
sourcepub fn with_cdf(cdf: CircuitDescription<S>) -> Self
pub fn with_cdf(cdf: CircuitDescription<S>) -> Self
Set the internal CDF provider