Encoder

Struct Encoder 

pub struct Encoder<WI, CI, T> { /* private fields */ }
An encoder for CDF format

Implementations

Source

impl<WI, CI, T> Encoder<WI, CI, T>

pub fn into_inner(self) -> T

Return the underlying encoder

Source

impl<WI, CI> Encoder<WI, CI, File>

pub fn init_file<P>( config: Config, witnesses: WI, constraints: CI, path: P, ) -> Result<Self>
where P: AsRef<Path>,

Initialize the encoder, filling a file with required bytes.

Check File::set_len

Source

impl<WI, CI, B> Encoder<WI, CI, BufWriter<B>>

pub fn init_buffer( config: Config, witnesses: WI, constraints: CI, buffer: B, ) -> Result<Self>

Initialize the encoder, filling the buffer with required bytes.

Source

impl<WI, CI> Encoder<WI, CI, Cursor<Vec<u8>>>

pub fn init_cursor(config: Config, witnesses: WI, constraints: CI) -> Self

Initialize the encoder, filling the buffer with required bytes.

Source

impl<W, WI, C, CI, T> Encoder<WI, CI, T>

pub fn write_all<P>(&mut self, provider: P) -> Result<usize>

Write all witnesses and constraints into the target