Struct dusk_cdf::IndexedWitness
source · [−]pub struct IndexedWitness { /* private fields */ }Expand description
Representation of an indexed witness.
Its index is the dense representation of the constraint system. Since CDF files will store witnesses first, it will be line (starting at zero) of the file.
Its origin will be the constraint that created this witness. Its None when the witness is
referenced on the same constraint it was created.
Implementations