pub struct Polynomial {
pub selectors: Selectors,
pub witnesses: WiredWitnesses,
pub evaluation: bool,
}Expand description
PLONK polynomial expression representation with its selectors and witnesses.
Fields
selectors: SelectorsSelectors of the polynomial
witnesses: WiredWitnessesWired witnesses
evaluation: boolPolynomial evaluated to zero?
Implementations
Sourceimpl Polynomial
impl Polynomial
Sourcepub const fn new(
selectors: Selectors,
witnesses: WiredWitnesses,
evaluation: bool,
) -> Self
pub const fn new( selectors: Selectors, witnesses: WiredWitnesses, evaluation: bool, ) -> Self
Create a new polynomial with evaluation to either correct or incorrect
Sourcepub const fn witnesses(&self) -> &WiredWitnesses
pub const fn witnesses(&self) -> &WiredWitnesses
Wired witnesses