ZkDebugger

Struct ZkDebugger 

pub struct ZkDebugger<S> { /* private fields */ }
ZKP Debugger with CDF backend

Implementations

Source

impl<S> ZkDebugger<S>

pub const fn config(&self) -> &Config

Configuration of the CDF file

pub const fn preamble(&self) -> &Preamble

Preamble for the CDF file

pub fn add_breakpoint(&mut self, source: String, line: Option<u64>) -> usize

Add a breakpoint to the provided source/line

If line is None, the breakpoint will be triggered in any incidence of source

pub fn remove_breakpoint(&mut self, id: usize) -> Option<Breakpoint>

Remove a breakpoint with the provided id.

If the id is not in the set, will return None.

pub fn fetch_breakpoint(&mut self, id: usize) -> Option<&Breakpoint>

Fetch a breakpoint from an id returned from add_breakpoint.

Source

impl<S> ZkDebugger<S>
where S: Read + Seek,

pub fn from_reader(source: S) -> Result<Self>

Create a CDF with the provided source and use it as backend for the debugger

pub fn fetch_current_constraint(&mut self) -> Result<Constraint<'_>>

Attempt to fetch the current constraint from the source

pub fn fetch_constraint(&mut self, idx: usize) -> Result<Constraint<'_>>

Attempt to read an indexed constraint from the source

pub fn fetch_witness(&mut self, idx: usize) -> Result<Witness<'_>>

Attempt to read an indexed witness from the source

pub fn afore(&mut self) -> Result<State>

Move to previous source/line.

May jump more than one constraint in case we have multiple constraints defined in a single source/file tuple.

pub fn cont(&mut self) -> Result<State>

Continue the execution until EOF, breakpoint, or invalid constraint.

pub fn goto(&mut self, idx: usize) -> Result<State>

Attempt to jump to a given constraint

pub fn step(&mut self) -> Result<State>

Move to next source/line.

May jump more than one constraint in case we have multiple constraints defined in a single source/file tuple.

pub fn turn(&mut self) -> Result<State>

Reverse the execution until BOF, breakpoint, or invalid constraint.

Methods from Deref<Target = CircuitDescription<S>>

pub fn preamble(&self) -> &Preamble

Decoded preamble

pub fn source_name_contains(&self, name: &str) -> bool

Check if the provided name is contained within the available source names

pub fn fetch_constraint(&mut self, idx: usize) -> Result<Constraint<'_>>

Attempt to read an indexed constraint from the source

pub fn fetch_witness(&mut self, idx: usize) -> Result<Witness<'_>>

Attempt to read an indexed witness from the source