Struct dusk_cdf::CircuitDescription
source · [−]pub struct CircuitDescription<S> { /* private fields */ }Expand description
A circuit description file
Since circuit descriptions are often large, it will perform lazy disk I/O, loading only the required data to satisfy the user operation.
Implementations
sourceimpl CircuitDescription<File>
impl CircuitDescription<File>
sourceimpl<S> CircuitDescription<S> where
S: Read,
impl<S> CircuitDescription<S> where
S: Read,
sourceimpl<S> CircuitDescription<S> where
S: Read + Seek,
impl<S> CircuitDescription<S> where
S: Read + Seek,
sourcepub fn from_reader(source: S) -> Result<Self>
pub fn from_reader(source: S) -> Result<Self>
Create a new circuit description instance.
sourcepub fn fetch_constraint(&mut self, idx: usize) -> Result<Constraint>
pub fn fetch_constraint(&mut self, idx: usize) -> Result<Constraint>
Attempt to read an indexed constraint from the source
sourcepub fn fetch_witness(&mut self, idx: usize) -> Result<Witness>
pub fn fetch_witness(&mut self, idx: usize) -> Result<Witness>
Attempt to read an indexed witness from the source
sourcepub fn fetch_source(
&mut self,
idx: usize
) -> Result<FixedText<{ Source::PATH_LEN }>>
pub fn fetch_source(
&mut self,
idx: usize
) -> Result<FixedText<{ Source::PATH_LEN }>>
Attempt to fetch a path from source cache
sourceimpl<S> CircuitDescription<S>
impl<S> CircuitDescription<S>