pub struct Context<S> { /* private fields */ }
Encoding and decoding context to be defined by the reader/writer and consumed by the elements

Implementations

Create a new context without CDF backend

Set a source cache id in the context. The next witness or constraint encoding should consume it instead of storing the raw path

Consume a previously set source cache id.

Set the internal CDF provider

Fetch the internal source

Attempt to fetch a path from source cache