pub struct Encoder<WI, CI, T> { /* private fields */ }
An encoder for CDF format

Implementations

Return the inner target

Intialize a preamble from a witness & constraints iterator

Initialize the encoder, filling a file with required bytes.

Check File::set_len

Initialize the encoder, filling the buffer with required bytes.

Initialize the encoder, filling the cursor with required bytes.

Write all witnesses and constraints into the target