pub struct Encoder<WI, CI, T> { /* private fields */ }Expand description
An encoder for CDF format
Implementations
sourceimpl<WI, CI, T> Encoder<WI, CI, T>
impl<WI, CI, T> Encoder<WI, CI, T>
sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Return the inner target
sourceimpl<W, WI, C, CI, T> Encoder<WI, CI, T> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
impl<W, WI, C, CI, T> Encoder<WI, CI, T> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
sourceimpl<W, WI, C, CI> Encoder<WI, CI, File> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
impl<W, WI, C, CI> Encoder<WI, CI, File> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
sourceimpl<W, WI, C, CI, B> Encoder<WI, CI, BufWriter<B>> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
B: Write + Seek,
impl<W, WI, C, CI, B> Encoder<WI, CI, BufWriter<B>> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
B: Write + Seek,
sourcepub fn init_buffer(
config: Config,
witnesses: WI,
constraints: CI,
buffer: B
) -> Result<Self>
pub fn init_buffer(
config: Config,
witnesses: WI,
constraints: CI,
buffer: B
) -> Result<Self>
Initialize the encoder, filling the buffer with required bytes.
sourceimpl<W, WI, C, CI> Encoder<WI, CI, Cursor<Vec<u8>>> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
impl<W, WI, C, CI> Encoder<WI, CI, Cursor<Vec<u8>>> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
sourcepub fn init_cursor(config: Config, witnesses: WI, constraints: CI) -> Self
pub fn init_cursor(config: Config, witnesses: WI, constraints: CI) -> Self
Initialize the encoder, filling the cursor with required bytes.
sourceimpl<W, WI, C, CI, T> Encoder<WI, CI, T> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
T: Write + Seek,
impl<W, WI, C, CI, T> Encoder<WI, CI, T> where
W: Borrow<Witness>,
WI: Iterator<Item = W> + ExactSizeIterator,
C: Borrow<Constraint>,
CI: Iterator<Item = C> + ExactSizeIterator,
T: Write + Seek,